# TODO - consider adding `validation` blocks to any that are ~enums although it
#        may be better to implement those validations at the helm level so the
#        chart install will fail fast instead of getting to the terraform plan
#        phase.

variable "model_name" {
  type        = string
  description = "The name of the model"
}

variable "endpoint_config_name" {
  type        = string
  description = "The name of the endpoint configuration"
}

variable "endpoint_name" {
  type        = string
  description = "The name of the endpoint"
}

variable "execution_role_arn" {
  type        = string
  description = "The ARN of execution role"
}

variable "model_bucket_name" {
  type        = string
  default     = ""
  description = "The name of the model S3 bucket"
}

variable "model_bucket_path" {
  type        = string
  default     = ""
  description = "The path where model artifacts are stored in the S3 bucket"
}

variable "container_image" {
  type        = string
  description = "The name of the inference code image"
}

variable "instance_type" {
  type        = string
  description = "The type of instance to start"
}

variable "initial_instance_count" {
  type        = number
  description = "Initial number of instances used for auto-scaling"
}

variable "production_variant_name" {
  type        = string
  default     = ""
  description = "The name of the variant"
}

variable "model_env_vars" {
  type        = map(string)
  default     = {}
  description = "Environment variables for the container image. A list of key value pairs."
}

variable "skip_model_creation" {
  type        = bool
  default     = false
  description = "Skip model creation if model already exists"
}

variable "tags" {
  type        = map(string)
  description = "Tags for SageMaker Endpoint"
}

variable "min_capacity" {
  type        = number
  description = "Minimum Capacity for autoscaling"
}

variable "max_capacity" {
  type        = number
  description = "Maximum Capacity for autoscaling"
}

variable "policy_type" {
  type        = string
  description = "The type of policy. Target tracking policy, requires policy_type = 'TargetTrackingScaling'"
}

variable "target_value" {
  type        = number
  description = "Target value for the metric."
}

variable "scale_in_cooldown" {
  type        = number
  description = "Amount of time, in seconds, after a scale in activity completes before another scale in activity can start."
}

variable "scale_out_cooldown" {
  type        = number
  description = "Amount of time, in seconds, after a scale out activity completes before another scale out activity can start."
}

variable "disable_scale_in" {
  type        = bool
  default     = false
  description = "Whether scale in by the target tracking policy is disabled. The default value is false."
}